Learn R Programming

pirouette (version 1.6.9)

check_error_measure_params: Checks if the argument is a valid error_measure parameters structure, as created by create_error_measure_params. Will stop if not.

Description

Checks if the argument is a valid error_measure parameters structure, as created by create_error_measure_params. Will stop if not.

Usage

check_error_measure_params(error_measure_params)

Value

nothing. Will stop if nit

Arguments

error_measure_params

parameter set to specify how the error between the given phylogeny and the Bayesian posterior is determined. Use create_error_measure_params to create such a parameter set

Author

Richèl J.C. Bilderbeek, Giovanni Laudanno

Examples

Run this code
# Check cleanup by other functions
beastier::check_empty_beaustier_folders()

check_error_measure_params(create_error_measure_params())

Run the code above in your browser using DataLab