If all the candidates share a same MCMC, they share the same tracelog and treelog. In this way, one can predict where the parameter estimates (the trace) and posterior trees are written to, as only the best candidate will run.
check_experiments_candidates_have_same_mcmcs(experiments)nothing
a list of one or more pirouette experiments, as can be created by create_experiment. If more than one experiment is provided and a "generative" experiment is part of them, the "generative" one has to be the first in the list. See also:
Use check_experiments to check the list of experiments for validity
Use create_all_experiments to create experiments with all combinations of tree model, clock model and tree priors
Use create_all_bd_experiments to create experiments with all combinations of tree model, clock model and tree priors, except for only using birth-death tree priors
Use create_all_coal_experiments to create all experiments with all combinations of tree model, clock model and tree priors, except for only coalescent tree priors
Use shorten_experiments to shorten the run time of the list of experiments
Richèl J.C. Bilderbeek