Learn R Programming

pirouette (version 1.6.9)

check_inference_conditions: Checks if inference conditions are valid as created by create_inference_conditions. Will stop if not.

Description

Checks if inference conditions are valid as created by create_inference_conditions. Will stop if not.

Usage

check_inference_conditions(inference_conditions)

Value

nothing. Will stop if not

Arguments

inference_conditions

conditions under which the inference model is used in the inference

Author

Giovanni Laudanno, Richèl J.C. Bilderbeek

Examples

Run this code
check_inference_conditions(create_inference_conditions())

Run the code above in your browser using DataLab