Learn R Programming

pirouette (version 1.6.9)

check_pir_out: Checks if the argument is a valid pirouette parameter set.

Description

Will stop if not. A valid pirouette parameter set can be created by create_pir_params.

Usage

check_pir_out(pir_out)

Value

nothing. Will stop if not

Arguments

pir_out

the output of pir_run

Author

Richèl J.C. Bilderbeek

Details

A pir_out contains:

  1. tree true or twin tree

  2. inference_model generative or candidate

  3. inference_model_weight

  4. site_model the site model name

  5. clock_model the clock model name

  6. tree_prior the tree model name

  7. error_1, error_2, etcetera: inference errors

Examples

Run this code
check_pir_out(create_test_pir_run_output())

Run the code above in your browser using DataLab