Learn R Programming

pirouette (version 1.6.9)

check_pir_params: Checks if the argument is a valid pirouette parameter set.

Description

Will stop if not. A valid pirouette parameter set can be created by create_pir_params.

Usage

check_pir_params(pir_params)

Value

nothing. Will stop if not

Arguments

pir_params

the parameters of pirouette. They are created by create_pir_params.

Author

Giovanni Laudanno, Richèl J.C. Bilderbeek

Examples

Run this code
if (beautier::is_on_ci()) {
  check_pir_params(create_test_pir_params())
}

Run the code above in your browser using DataLab