Learn R Programming

pirouette (version 1.6.9)

check_pir_paramses: Check if all elements in the list of pir_params are valid.

Description

Will stop if not

Usage

check_pir_paramses(pir_paramses)

Value

nothing

Arguments

pir_paramses

a list of pirouette parameters, each element created by create_pir_params.

Author

Richèl J.C. Bilderbeek