Will stop if not
check_sim_twal_fun(sim_twal_fun)nothing
function to simulate a
twin alignment with.
This function must have two arguments called twin_phylogeny (which
will hold the twin phylogeny) and true_alignment (which will
hold the alignment simulated from the true phylogeny). The
return type must be DNAbin.
Use check_sim_twal_fun to verify if the function has the right signature and output.
Some standard functions:
Use get_copy_tral_fun to get a function (copy_true_alignment) that copies a true to alignment to create a twin alignment
Use get_sim_twal_with_std_nsm_fun to get a function (sim_twal_with_std_nsm) that simulates a twin alignment using a standard site model
Use get_sim_twal_same_n_muts_fun to get a function (sim_twal_with_same_n_mutation) that simulates -using a standard model- a twin alignment with as much mutations compared to the root sequence as the true alignment has
Use sim_twal_with_lns_nsm that simulates a twin alignment using a linked node substitution model
Use sim_twal_with_uns_nsm that simulates a twin alignment using an unlinked node substitution model
Richèl J.C. Bilderbeek
Use check_sim_tral_fun to check a function to generate a true alignment. Use check_sim_twin_tree_fun to check a function to generate a twin phylogeny.