Learn R Programming

pirouette (version 1.6.9)

check_sim_twin_tree_fun: Check if the sim_twin_tree_fun is valid

Description

Will stop if not

Usage

check_sim_twin_tree_fun(sim_twin_tree_fun)

Value

nothing

Arguments

sim_twin_tree_fun

function to simulate a twin tree with. This function must have one argument called phylogeny of type phylo and have a return type of type phylo as well.

Some standard functions:

  • Use create_sim_yule_twin_tree_fun to use a Yule (aka Pure Birth) process

  • Use create_copy_twtr_from_true_fun to for a function that copies the true tree

  • Use get_sim_bd_twin_tree_fun to use a Birth-Death process

Author

Richèl J.C. Bilderbeek

See Also

Use check_sim_twal_fun to check a function to generate a twin alignment.