Learn R Programming

pirouette (version 1.6.9)

check_tree_types: Checks if the tree types are valid Will stop if not.

Description

Checks if the tree types are valid Will stop if not.

Usage

check_tree_types(tree_types)

Value

nothing. Will stop if not

Arguments

tree_types

types of tree, a vector of true for a true phylogeny, and twin for a twin tree

Author

Richèl J.C. Bilderbeek

Examples

Run this code
check_tree_types(get_tree_types())

Run the code above in your browser using DataLab