Learn R Programming

pirouette (version 1.6.9)

check_twinning_params: Checks if the argument is a valid twinning parameters structure.

Description

Will stop if not. A valid twinning parameters structure can be created by create_twinning_params.

Usage

check_twinning_params(twinning_params)

Value

nothing. Will stop if nit

Arguments

twinning_params

can be NA if no twinning is desired, or can be the twinning parameters, as can be created by create_twinning_params

Author

Richèl J.C. Bilderbeek

Examples

Run this code
if (beautier::is_on_ci()) {
  check_twinning_params(create_twinning_params())
}

Run the code above in your browser using DataLab