Learn R Programming

pirouette (version 1.6.9)

check_twinning_params_names: Check that the twinning_params has all the list elements' names

Description

Check that the twinning_params has all the list elements' names

Usage

check_twinning_params_names(twinning_params)

Value

nothing

Arguments

twinning_params

can be NA if no twinning is desired, or can be the twinning parameters, as can be created by create_twinning_params

Author

Richèl J.C. Bilderbeek