Learn R Programming

pirouette (version 1.6.9)

combine_models: Combine a combination of site models, clock models and tree priors into a collection of inference models.

Description

If there are `x` site models, `y` clock models and `z` tree priors, this will result in `x * y * z` inference models.

Usage

combine_models(
  site_models = beautier::create_site_models(),
  clock_models = beautier::create_clock_models(),
  tree_priors = beautier::create_tree_priors()
)

Value

a list of inference models (see create_inference_model)

Arguments

site_models

a list of one or more site models, as created by create_site_model

clock_models

a list of one or more clock models, as created by create_clock_model

tree_priors

a list of one or more tree priors, as created by create_tree_prior

Examples

Run this code
if (beautier::is_on_ci()) {
  site_models <- beautier::create_site_models()
  clock_models <- beautier::create_clock_models()
  tree_priors <- beautier::create_tree_priors()

  inference_models <- combine_models(
    site_models = site_models,
    clock_models = clock_models,
    tree_priors = tree_priors
  )
}

Run the code above in your browser using DataLab