Learn R Programming

pirouette (version 1.6.9)

copy_true_alignment: Adapter function to create a twin alignment by simply copying the true alignment

Description

Adapter function to create a twin alignment by simply copying the true alignment

Usage

copy_true_alignment(
  true_alignment,
  twin_phylogeny = "irrelevant",
  root_sequence = "irrelevant"
)

Value

the true alignment

Arguments

true_alignment

a DNA alignment, of class DNAbin

twin_phylogeny

a phylogeny of class phylo

root_sequence

the DNA sequence at the root of the phylogeny. By default, this will consist out of an equal amount of each letter Use check_root_sequence to check if a root sequence is valid.

Author

Richèl J.C. Bilderbeek, Giovanni Laudanno

Examples

Run this code
# Check cleanup by other functions
beastier::check_empty_beaustier_folders()

true_alignment <- get_test_alignment()
twin_alignment <- copy_true_alignment(true_alignment)

# twin_alignment equals true_alignment

Run the code above in your browser using DataLab