Learn R Programming

pirouette (version 1.6.9)

create_blocked_dna: Create a 'blocked' DNA sequence, which is a sequence with four equal-sized nucleotide sections

Description

Create a 'blocked' DNA sequence, which is a sequence with four equal-sized nucleotide sections

Usage

create_blocked_dna(length)

Value

a string

Arguments

length

number of nucleotides. Must be a multiple of four.

Author

Richèl J.C. Bilderbeek

See Also

Use create_mono_nuc_dna to create a mono-nucleotide DNA sequence.

Examples

Run this code
# Will be acgt
create_blocked_dna(length = 4)
# Will be aaccggtt
create_blocked_dna(length = 8)

Run the code above in your browser using DataLab