Learn R Programming

pirouette (version 1.6.9)

create_copy_twtr_from_true_fun: Create a function that can simulate the twin tree from the true tree, by just copying the true tree

Description

Create a function that can simulate the twin tree from the true tree, by just copying the true tree

Usage

create_copy_twtr_from_true_fun()

Arguments

Value

a function

Author

Richèl J.C. Bilderbeek

See Also

Use create_sim_yule_twin_tree_fun to get a function to produce a Yule tree. Use get_sim_bd_twin_tree_fun to get a function to produce a Birth-Death tree.

Examples

Run this code
f <- create_copy_twtr_from_true_fun()
phylo_in <- ape::read.tree(text = "((A:1, B:1):1, C:2);")
f(phylo_in)

Run the code above in your browser using DataLab