Learn R Programming

pirouette (version 1.6.9)

create_exemplary_dd_tree: Create an exemplary diversity-dependent (DD) birth-death tree.

Description

Create an exemplary diversity-dependent (DD) birth-death tree, that is, a DD tree with a strong DD effect. The DD tree produced most likely has the desired number of taxa, but this is not always the case.

Usage

create_exemplary_dd_tree(n_taxa = 6, crown_age = 10, extinction_rate = 0.1)

Value

a phylo

Arguments

n_taxa

number of tree tips

crown_age

the fixed crown age of the posterior. Set to NA to let it be estimated

extinction_rate

per-species extinction rate

Author

Giovanni Laudanno, Richèl J.C. Bilderbeek

See Also

Use create_exemplary_dd_tree_giappo for a different way to generate exemplary trees with a strong DD effect.

Examples

Run this code
create_exemplary_dd_tree(
  n_taxa = 3,
  crown_age = 1
)

Run the code above in your browser using DataLab