the fixed crown age of the posterior. Set to NA
to let it be estimated
extinction_rate
per-species extinction rate
best_of_n_trees
simulate this number of DD trees with
the desired number of taxa,
Author
Giovanni Laudanno, Richèl J.C. Bilderbeek
Details
This algorithm does so, by simulating best_of_n_trees
trees, then picks the tree that has the gamma statistic furthest
away from zero.
Trees with such a gamma statistic, have the strongest DD effect, as these
deviate strongest from the expected exponential growth
that regular birth-death (BD) trees have.