Learn R Programming

pirouette (version 1.6.9)

create_mono_nuc_dna: Create a 'blocked' DNA sequence, which is a sequence with four equal-sized nucleotide sections

Description

Create a 'blocked' DNA sequence, which is a sequence with four equal-sized nucleotide sections

Usage

create_mono_nuc_dna(length, nucleotide = "a")

Value

a string

Arguments

length

number of nucleotides

nucleotide

number of nucleotides

Author

Richèl J.C. Bilderbeek

See Also

Use create_blocked_dna to create a DNA sequence of four equally-sized mono-noculeotide block

Examples

Run this code
# Creates 'aaa'
create_mono_nuc_dna(length = 3)

# Creates 'ccccc'
create_mono_nuc_dna(nucleotide = "c", length = 5)

Run the code above in your browser using DataLab