Learn R Programming

pirouette (version 1.6.9)

create_test_marg_liks: Create a testing marginal likelihoods data frame.

Description

Create a testing marginal likelihoods data frame.

Usage

create_test_marg_liks(
  site_models = beautier::create_site_models(),
  clock_models = beautier::create_clock_models(),
  tree_priors = beautier::create_tree_priors()
)

Value

a data frame

Arguments

site_models

a list of one or more site models, as created by create_site_model

clock_models

a list of one or more clock models, as created by create_clock_model

tree_priors

a list of one or more tree priors, as created by create_tree_prior

Author

Richèl J.C. Bilderbeek

Examples

Run this code
create_test_marg_liks()

Run the code above in your browser using DataLab