Learn R Programming

pirouette (version 1.6.9)

create_test_pir_run_output2: Create the same output of pir_run to be used for testing, but with more data

Description

Create the same output of pir_run to be used for testing, but with more data

Usage

create_test_pir_run_output2(add_twin = FALSE, add_best = FALSE, n_errors = 200)

Value

a data frame with errors, with as many rows as model selection parameter sets. The output can be checked using check_pir_out.

Arguments

add_twin

add rows for twin tree

add_best

add rows for best inference model

n_errors

number of errors in the pir_out

Author

Giovanni Laudanno, Richèl J.C. Bilderbeek

Examples

Run this code
  pir_plot(
    create_test_pir_run_output2(
      add_twin = TRUE,
      add_best = TRUE,
      n_errors = 1e2
    )
  )

Run the code above in your browser using DataLab