Learn R Programming

pirouette (version 1.6.9)

create_twin_tree: Create a twin tree

Description

It sets the seed with value twinning_params$rng_seed_twin_tree, then generates a tree by calling twinning_paramssim_twin_tree_fun on the given tree.

Usage

create_twin_tree(phylogeny, twinning_params = create_twinning_params())

Value

a phylogeny of type phylo

Arguments

phylogeny

a phylogeny of class phylo

twinning_params

can be NA if no twinning is desired, or can be the twinning parameters, as can be created by create_twinning_params

Author

Richèl J.C. Bilderbeek, Giovanni Laudanno

Examples

Run this code
phylogeny <- ape::read.tree(text = "((A:1, B:1):1, C:2);")
twin_phylogeny <- create_twin_tree(phylogeny)

Run the code above in your browser using DataLab