Learn R Programming

pirouette (version 1.6.9)

get_copy_tral_fun: Get a function to 'simulate' a twin alignment by simply copying the true alignment.

Description

Get a function to 'simulate' a twin alignment by simply copying the true alignment.

Usage

get_copy_tral_fun()

Arguments

Value

the function copy_true_alignment

See Also

See check_sim_twal_fun to the the other functions to simulate a twin alignment. Use sim_twin_alignment to use this function to create a twin alignment.

Examples

Run this code
f <- get_copy_tral_fun()
# This adapter function must be a sim_twin_alignment function
check_sim_twal_fun(f)

Run the code above in your browser using DataLab