Learn R Programming

pirouette (version 1.6.9)

get_gamma_error_fun: Get an error function that uses the difference in gamma statistic.

Description

Get an error function that uses the difference in gamma statistic.

Usage

get_gamma_error_fun()

Arguments

Value

an error function

Author

Richèl J.C. Bilderbeek

Examples

Run this code
error_fun <- get_gamma_error_fun()

phylogeny <- ape::read.tree(text = "((A:1.5, B:1.5):1.5, C:3.0);")

tree_1 <- ape::read.tree(text = "((A:1.0, B:1.0):2.0, C:3.0);")
tree_2 <- ape::read.tree(text = "((A:2.0, B:2.0):1.0, C:3.0);")
trees <- c(tree_1, tree_2)

error_fun(phylogeny, c(phylogeny))
error_fun(phylogeny, c(tree_1))
error_fun(phylogeny, c(tree_2))

Run the code above in your browser using DataLab