Learn R Programming

pirouette (version 1.6.9)

get_model_selections: Get the possible ways to select an inference model

Description

Get the possible ways to select an inference model

Usage

get_model_selections()

Arguments

Value

a character vector

Author

Richèl J.C. Bilderbeek

Examples

Run this code
get_model_selections()

Run the code above in your browser using DataLab