get_remove_hex_twin_fun: Get a function that removes the hex string from filenames.
Description
The default filenames created by beautier are temporary files,
such as /home/john/.cache/tracelog_82c5888db98.log (on Linux),
where /home/john/.cache is the location to a temporary folder
(on Linux) and tracelog_82c5888db98.log the filename.
The filename ends with a hex string (as is common for temporary files,
as tempfile does so). Because beautier puts an underscore
between the filename description (tracelog) and the hex
string, this function removes both.