Learn R Programming

pirouette (version 1.6.9)

get_temp_evidence_filename: Get the name for a temporary file to store the evidences (aka marginal likelihoods) as a comma-separated file

Description

Get the name for a temporary file to store the evidences (aka marginal likelihoods) as a comma-separated file

Usage

get_temp_evidence_filename()

Arguments

Value

one string