Learn R Programming

pirouette (version 1.6.9)

get_temp_fasta_filename: Get the name for a temporary file to store an alignment in the FASTA format

Description

Get the name for a temporary file to store an alignment in the FASTA format

Usage

get_temp_fasta_filename()

Arguments

Value

one string