Learn R Programming

pirouette (version 1.6.9)

get_temp_tree_filename: Get the name for a temporary file to store a tree in Newick format

Description

Get the name for a temporary file to store a tree in Newick format

Usage

get_temp_tree_filename()

Arguments

Value

one string