Learn R Programming

pirouette (version 1.6.9)

get_tree_and_model_descriptions: Internal function to create a mapping from a tree_and_model to a description

Description

Internal function to create a mapping from a tree_and_model to a description

Usage

get_tree_and_model_descriptions()

Arguments

Value

a tibble with columns tree_and_model

and description

Author

Richèl J.C. Bilderbeek, Giovanni Laudanno

Examples

Run this code
t <- get_tree_and_model_descriptions()
check_tree_and_models(t$tree_and_model)

Run the code above in your browser using DataLab