Learn R Programming

pirouette (version 1.6.9)

pir_run_distribution: Do multiple pirouette runs off a distribition of phylogenies

Description

This is a simple convenience functions: supply a phylogeny generator function and one or more pirouette parameter sets. For each parameters pair, pir_run is called with a phylogeny drawn from the phylogeny generator function.

Usage

pir_run_distribution(sim_phylo_fun, pir_paramses)

Value

a list of pir_run outputs.

Arguments

sim_phylo_fun

function that, each time when called, simulates one random tree.

pir_paramses

a list of pirouette parameters, each element created by create_pir_params.