Learn R Programming

pirouette (version 1.6.9)

pir_run_true_tree: Measure the error BEAST2 makes from a phylogeny

Description

The phylogeny can be the true tree or its twin.

Usage

pir_run_true_tree(true_phylogeny, pir_params)

Value

a data frame with errors, with as many rows as model selection parameter sets

Arguments

true_phylogeny

the true phylogeny; the actual evolutionary history of the species, of class phylo

pir_params

the parameters of pirouette. They are created by create_pir_params.

Author

Richèl J.C. Bilderbeek, Giovanni Laudanno

Examples

Run this code
if (beautier::is_on_ci()) {

  pir_params <- create_test_pir_params()

  # The user should never need to initialize the pir_params
  # but a develop calling this function needs to
 pir_params <- init_pir_params(pir_params)

  if (
    rappdirs::app_dir()$os != "win" &&
    beastier::is_beast2_installed()
  ) {
    pir_run_true_tree(
      true_phylogeny = ape::rcoal(4),
      pir_params = pir_params
    )
  }
}

Run the code above in your browser using DataLab