lns site modelCreate an alignment with the lns site model
sim_tral_with_lns_nsm(
true_phylogeny,
root_sequence,
subst_matrix = rep(1, 6),
branch_mutation_rate = 1,
node_mutation_rate = 1,
base_frequencies = rep(0.25, 4),
node_time = 0.001
)an alignment of type DNAbin
the true phylogeny; the actual evolutionary history of the species, of class phylo
the DNA sequence at the root of the phylogeny. By default, this will consist out of an equal amount of each letter Use check_root_sequence to check if a root sequence is valid.
nucleotide substitution matrix
mutation rate along the branch. See, among others, sim_unlinked for more details
mutation rate on the node. See, among others, sim_unlinked for more details
the four base frequencies (a, c, g, t) to be specified to create the rate matrix (i.e. Q matrix) used to simulate alignments
amount of time spent at the nodes. See, among others, sim_unlinked for more details
Richèl J.C. Bilderbeek
Use sim_tral_with_uns_nsm to simulate the true alignment with an unlinked node substitution model. Use sim_twal_with_lns_nsm to simulate the twin alignment with an linked node substitution model. Use get_sim_tral_with_lns_nsm_fun to get a partially evaluated unary function.