linked_node_sub (lns) site model.Adapter function to simulate an alignment
with the linked_node_sub (lns) site model.
sim_twal_with_uns_nsm(
twin_phylogeny,
root_sequence,
true_alignment = "irrelevant",
branch_subst_matrix = rep(1, 6),
node_subst_matrix = 1,
branch_mutation_rate = 1,
node_mutation_rate = 1,
base_frequencies = rep(0.25, 4),
node_time = 0.001
)an alignment of type DNAbin
a phylogeny of class phylo
the DNA sequence at the root of the phylogeny. By default, this will consist out of an equal amount of each letter Use check_root_sequence to check if a root sequence is valid.
a DNA alignment, of class DNAbin
substitution matrix along the branches. See, among others, sim_unlinked for more details
substitution matrix on the nodes. See, among others, sim_unlinked for more details
mutation rate along the branch. See, among others, sim_unlinked for more details
mutation rate on the node. See, among others, sim_unlinked for more details
the four base frequencies (a, c, g, t) to be specified to create the rate matrix (i.e. Q matrix) used to simulate alignments
amount of time spent at the nodes. See, among others, sim_unlinked for more details
Richèl J.C. Bilderbeek
Use sim_twal_with_lns_nsm to simulate the true alignment with a linked node substitution model. Use sim_tral_with_uns_nsm to simulate the twin alignment with an unlinked node substitution model.