Learn R Programming

pirouette (version 1.6.9)

will_measure_evidence: Determine if there is an experiment in which the evidence will be measured.

Description

Determine if there is an experiment in which the evidence will be measured.

Usage

will_measure_evidence(pir_params)

Value

TRUE if yes, FALSE otherwise

Arguments

pir_params

the parameters of pirouette. They are created by create_pir_params.

Examples

Run this code
if (beautier::is_on_ci()) {

  if (rappdirs::app_dir()$os != "win") {
    pir_params <- create_test_pir_params_setup(has_candidate = TRUE)

    # Yes, the evidence will be measured on Linux with candidate models
    will_measure_evidence(pir_params)
  }

  pir_params <- create_test_pir_params_setup(has_candidate = FALSE)
  # No, the evidence will be measured without candidate models
  will_measure_evidence(pir_params)

}

Run the code above in your browser using DataLab