check_experiments_all_inference_models_are_unique: Internal function
Description
Internal function to check if all experiments have unique inference models.
Will stop if two models have a same site and clock and tree prior.
Note that experiments that differ in their MRCA priors only
are classified being the same.
a list of one or more pirouette experiments,
as can be created by create_experiment. If more than one experiment
is provided and a "generative" experiment is part of them, the "generative"
one has to be the first in the list. See also:
Use check_experiments to check the list of
experiments for validity
Use create_all_experiments to create experiments with
all combinations of tree model, clock model and tree priors
Use create_all_bd_experiments to create experiments
with all combinations of tree model, clock model and tree priors,
except for only using birth-death tree priors
Use create_all_coal_experiments to create all experiments
with all combinations of tree model, clock model and tree priors,
except for only coalescent tree priors
Use shorten_experiments to shorten the run time
of the list of experiments