powered by
Checks if inference conditions are valid as created by create_inference_conditions. Will stop if not.
check_inference_conditions(inference_conditions)
nothing. Will stop if not
conditions under which the inference model is used in the inference
Giovanni Laudanno, Richèl J.C. Bilderbeek
check_inference_conditions(create_inference_conditions())
Run the code above in your browser using DataLab