Will stop if not
check_sim_tral_fun(sim_tral_fun)nothing
function to simulate a
true alignment with.
This function must have two arguments,
called true_phylogeny (which will hold the true phylogeny)
and root_sequence (which holds the DNA root sequence).
The return type must be DNAbin.
Use check_sim_tral_fun to verify if the function has the right signature and output.
Some standard functions:
Use get_sim_tral_with_std_nsm_fun to get a function (sim_tral_with_std_nsm) the use a standard site model.
Use get_sim_tral_with_lns_nsm_fun to get a function (sim_tral_with_lns_nsm) the use a linked node substitution site model.
Use get_sim_tral_with_uns_nsm_fun to get a function (sim_tral_with_uns_nsm) the use an unlinked node substitution site model.
Richèl J.C. Bilderbeek
Use check_sim_twal_fun to check a function to generate a twin alignment