sim_twin_tree_fun is validWill stop if not
check_sim_twin_tree_fun(sim_twin_tree_fun)nothing
function to simulate a twin tree with.
This function must have one argument called phylogeny
of type phylo and have a return type of type phylo
as well.
Some standard functions:
Use create_sim_yule_twin_tree_fun to use a Yule (aka Pure Birth) process
Use create_copy_twtr_from_true_fun to for a function that copies the true tree
Use get_sim_bd_twin_tree_fun to use a Birth-Death process
Richèl J.C. Bilderbeek
Use check_sim_twal_fun to check a function to generate a twin alignment.