powered by
Checks if the tree types are valid Will stop if not.
check_tree_types(tree_types)
nothing. Will stop if not
types of tree, a vector of true for a true phylogeny, and twin for a twin tree
true
twin
Richèl J.C. Bilderbeek
check_tree_types(get_tree_types())
Run the code above in your browser using DataLab