powered by
Will stop if not. A valid twinning parameters structure can be created by create_twinning_params.
check_twinning_params(twinning_params)
nothing. Will stop if nit
can be NA if no twinning is desired, or can be the twinning parameters, as can be created by create_twinning_params
NA
Richèl J.C. Bilderbeek
if (beautier::is_on_ci()) { check_twinning_params(create_twinning_params()) }
Run the code above in your browser using DataLab