create_exemplary_dd_tree: Create an exemplary diversity-dependent (DD) birth-death tree.
Description
Create an exemplary diversity-dependent (DD) birth-death tree,
that is, a DD tree with a strong DD effect.
The DD tree produced most likely has the desired number
of taxa, but this is not always the case.