powered by
Create the same output of pir_run to be used for testing, but with more data
create_test_pir_run_output2(add_twin = FALSE, add_best = FALSE, n_errors = 200)
a data frame with errors, with as many rows as model selection parameter sets. The output can be checked using check_pir_out.
add rows for twin tree
add rows for best inference model
number of errors in the pir_out
Giovanni Laudanno, Richèl J.C. Bilderbeek
pir_plot( create_test_pir_run_output2( add_twin = TRUE, add_best = TRUE, n_errors = 1e2 ) )
Run the code above in your browser using DataLab