powered by
Generate twin branching times given estimated lambda and mu and the original tree
create_twin_branching_times(lambda, mu, phylogeny, n_replicates, method)
twin branching times
per-lineage speciation rate
per-species extinction rate
a phylogeny of class phylo
number of replicas to evaluate in order to create the twin tree
determines how to create the twin tree
'random_tree' just produces a random tree;
'max_clade_cred' simulates n_replicates trees and uses maxCladeCred to create a consensus tree;
n_replicates
'max_likelihood' simulates n_replicates trees and selects the most likely;
Giovanni Laudanno, Richèl J.C. Bilderbeek
phylogeny <- ape::read.tree(text = "(((A:1, B:1):1, C:2):1, D:3);") create_twin_branching_times( lambda = 0.1, mu = 1.0, phylogeny = phylogeny, n_replicates = 1, method = "random_tree" )
Run the code above in your browser using DataLab