powered by
It sets the seed with value twinning_params$rng_seed_twin_tree, then generates a tree by calling twinning_paramssim_twin_tree_fun on the given tree.
twinning_params$rng_seed_twin_tree
twinning_paramssim_twin_tree_fun
create_twin_tree(phylogeny, twinning_params = create_twinning_params())
a phylogeny of type phylo
a phylogeny of class phylo
can be NA if no twinning is desired, or can be the twinning parameters, as can be created by create_twinning_params
NA
Richèl J.C. Bilderbeek, Giovanni Laudanno
phylogeny <- ape::read.tree(text = "((A:1, B:1):1, C:2);") twin_phylogeny <- create_twin_tree(phylogeny)
Run the code above in your browser using DataLab