get_temp_evidence_filename: Get the name for a temporary file to store the
evidences (aka marginal likelihoods) as
a comma-separated file
Description
Get the name for a temporary file to store the
evidences (aka marginal likelihoods) as
a comma-separated file
Usage
get_temp_evidence_filename()