This is a simple convenience functions: supply a phylogeny generator function and one or more pirouette parameter sets. For each parameters pair, pir_run is called with a phylogeny drawn from the phylogeny generator function.
pir_run_distribution(sim_phylo_fun, pir_paramses)a list of pir_run outputs.
function that, each time when called, simulates one random tree.
a list of pirouette parameters, each element created by create_pir_params.